@@ -1,7 +1,7 @@
 import httpx
 import typer
 
-from neosctl import util
+from neosctl import schema, util
 from neosctl.auth import ensure_login
 from neosctl.util import process_response
 
@@ -439,6 +439,64 @@ def product_field_description(
     process_response(r)
 
 
+@product_app.command("quality-rules")
+def quality_rules(
+    ctx: typer.Context,
+) -> None:
+    """Get quality expectations rules."""
+
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.get(
+            ctx,
+            _metadata_url(ctx, "/quality/rules"),
+        )
+
+    r = _request(ctx)
+
+    process_response(r)
+
+
+@product_app.command("edit-quality-expectations")
+def edit_product_quality_expectations(
+    ctx: typer.Context,
+    product_identifier: str = typer.Argument(
+        ...,
+        help="Data Product identifier",
+        callback=util.sanitize,
+    ),
+    filepath: str = typer.Option(
+        ...,
+        "--filepath",
+        "-f",
+        help="Filepath of the details json payload",
+        callback=util.sanitize,
+    ),
+) -> None:
+    """Update data product quality expectations."""
+
+    @ensure_login
+    def _request(ctx: typer.Context, uqe: schema.UpdateQualityExpectations) -> httpx.Response:
+        return util.put(
+            ctx,
+            _metadata_url(ctx, f"/product/{product_identifier}/quality/expectation"),
+            json=uqe.dict(exclude_none=True, by_alias=True),
+        )
+
+    fp = util.get_file_location(filepath)
+    details = util.load_object_file(fp, "")
+
+    uqe = schema.UpdateQualityExpectations(
+        custom_details=details["custom_details"],  # type: ignore[reportGeneralTypeIssues]
+        weights=details["weights"],  # type: ignore[reportGeneralTypeIssues]
+        thresholds=details["thresholds"],  # type: ignore[reportGeneralTypeIssues]
+    )
+
+    r = _request(ctx, uqe)
+
+    process_response(r)
+
+
 @product_app.command("quality-expectations")
 def product_quality_expectations(
     ctx: typer.Context,
