@@ -1,6 +1,3 @@
-import json
-import mimetypes
-import pathlib
 import sys
 import typing
 
@@ -13,7 +10,7 @@ else:
 
 import typer
 
-from neosctl import constant, schema, util
+from neosctl import schema, util
 from neosctl.auth import ensure_login
 from neosctl.util import process_response
 
@@ -24,62 +21,6 @@ def _product_url(ctx: typer.Context) -> str:
     return "{}/product".format(ctx.obj.get_gateway_api_url().rstrip("/"))
 
 
-special_delimiters = {
-    r"\t": "\t",
-}
-
-
-@app.command(name="template")
-def template(
-    ctx: typer.Context,
-    name: str = typer.Argument(..., help="Data Product name", callback=util.sanitize),
-    filepath: str = typer.Option(..., "--filepath", "-f", help="Filepath of the csv template", callback=util.sanitize),
-    output_dir: str = typer.Option(
-        ...,
-        "--output-dir",
-        "-o",
-        help="Output directory for the json template",
-        callback=util.sanitize,
-    ),
-    delimiter: str = typer.Option(",", "--delimiter", "-d", help="csv delimiter", callback=util.sanitize),
-    quotechar: typing.Optional[str] = typer.Option(
-        None,
-        "--quote-char",
-        "-q",
-        help="csv quote char",
-        callback=util.sanitize,
-    ),
-) -> None:
-    """Generate a data product schema template from a csv.
-
-    Given a csv with a header row, generate a template field schema.
-    """
-
-    @ensure_login
-    def _request(ctx: typer.Context, f: typing.IO, mime_type: typing.Optional[str]) -> httpx.Response:
-        params = {k: v for k, v in [("delimiter", delimiter), ("quotechar", quotechar)] if v is not None}
-
-        return util.post(
-            ctx,
-            f"{_product_url(ctx)}/template",
-            params=params,
-            files={"csv_file": ("upload.csv", f, mime_type)},
-        )
-
-    fp = util.get_file_location(filepath)
-    mime_type = mimetypes.guess_type(fp)
-
-    with fp.open("rb") as f:
-        r = _request(ctx, f, mime_type[0])
-
-    if r.status_code >= constant.BAD_REQUEST_CODE:
-        process_response(r)
-
-    fp = pathlib.Path(output_dir) / f"{name}.json"
-    with fp.open("w") as f:
-        json.dump(r.json(), f, indent=4)
-
-
 @app.command(name="create")
 def create(
     ctx: typer.Context,
