@@ -25,8 +25,6 @@ class IcebergTableProperties(pydantic.BaseModel):
     partitioning: Optional[List[str]] = None
     location: Optional[str] = None
     format_version: Optional[int] = None
-    orc_bloom_filter_columns: Optional[List[str]] = None
-    orc_bloom_filter_fpp: Optional[float] = None
 
 
 class StreamingSchemaBase(pydantic.BaseModel):
@@ -86,6 +84,39 @@ class UpdateDataProductSchema(pydantic.BaseModel):
     details: Union[StreamingDataProductSchema, StoredDataProductSchema] = pydantic.Field(..., discriminator="type")
 
 
+class ExpectationItem(pydantic.BaseModel):
+    expectation_type: str
+    kwargs: dict
+    meta: dict
+
+
+class ExpectationWeights(pydantic.BaseModel):
+    accuracy: float
+    completeness: float
+    consistency: float
+    uniqueness: float
+    validity: float
+
+
+class ExpectationColumnThresholds(BaseModel):
+    accuracy: Union[float, None]
+    completeness: Union[float, None]
+    consistency: Union[float, None]
+    uniqueness: Union[float, None]
+    validity: Union[float, None]
+
+
+class ExpectationThresholds(BaseModel):
+    table: float
+    columns: Dict[str, ExpectationColumnThresholds]
+
+
+class UpdateQualityExpectations(pydantic.BaseModel):
+    custom_details: List[ExpectationItem]
+    weights: Union[ExpectationWeights, None]
+    thresholds: Union[ExpectationThresholds, None]
+
+
 class RegisterCore(BaseModel):
     partition: str
     name: str
@@ -111,7 +142,7 @@ class ExternalDatabaseConnectionDetails(pydantic.BaseModel):
     password_env: str
 
 
-class CSVFileConnectionDetails(pydantic.BaseModel):
+class FileConnectionDetails(pydantic.BaseModel):
     type: Literal["file"]  # noqa: A003
     url: str
     access_key_env: Optional[str]
@@ -122,7 +153,7 @@ class CreateConnection(pydantic.BaseModel):
     name: str
     details: Union[
         ExternalDatabaseConnectionDetails,
-        CSVFileConnectionDetails,
+        FileConnectionDetails,
     ]
 
 
@@ -136,8 +167,21 @@ class QueryConnectionParams(pydantic.BaseModel):
     query: str
 
 
+class CSVConnectionParams(pydantic.BaseModel):
+    type: Literal["csv"]  # noqa: A003
+    path: Union[str, List[str]]
+    has_header: Optional[bool]
+    delimiter: Optional[str]
+    quote_char: Optional[str]
+    escape_char: Optional[str]
+
+
 class CreateSourceConnection(pydantic.BaseModel):
-    details: Union[TableConnectionParams, QueryConnectionParams]
+    details: Union[
+        TableConnectionParams,
+        QueryConnectionParams,
+        CSVConnectionParams,
+    ]
 
 
 class Auth(BaseModel):
