@@ -1,4 +1,3 @@
-import mimetypes
 import typing
 
 import httpx
@@ -344,64 +343,6 @@ def trigger_job(
     process_response(r)
 
 
-@app.command()
-def csv_job(
-    ctx: typer.Context,
-    product_identifier: str = typer.Argument(
-        ...,
-        help="Data Product identifier",
-        callback=util.sanitize,
-    ),
-    delimiter: str = typer.Option(",", "--delimiter", "-d", help="csv delimiter", callback=util.sanitize),
-    quotechar: typing.Optional[str] = typer.Option(
-        None,
-        "--quote-char",
-        "-q",
-        help="csv quote char",
-        callback=util.sanitize,
-    ),
-    csv_write_mode: typing.Optional[str] = typer.Option(
-        None,
-        "--write-mode",
-        "-w",
-        help="csv write mode [overwrite|append]",
-        callback=util.sanitize,
-    ),
-    job_filepath: str = typer.Option(..., "--job-filepath", "-f", callback=util.sanitize),
-) -> None:
-    """Ingest a csv file into a data product.
-
-    Upload a csv file for processing into a data product.
-    """
-
-    @ensure_login
-    def _request(ctx: typer.Context, f: typing.IO, mime_type: typing.Optional[str]) -> httpx.Response:
-        params = {
-            k: v
-            for k, v in [
-                ("delimiter", delimiter),
-                ("quotechar", quotechar),
-                ("csv_write_mode", csv_write_mode),
-            ]
-            if v is not None
-        }
-
-        return util.post(
-            ctx,
-            f"{_spark_url(product_identifier, ctx.obj.gateway_api_url)}/csv",
-            params=params,
-            files={"csv_file": ("upload.csv", f, mime_type)},
-        )
-
-    fp = util.get_file_location(job_filepath)
-    mime_type = mimetypes.guess_type(fp)
-
-    with fp.open("rb") as f:
-        r = _request(ctx, f, mime_type[0])
-
-    process_response(r)
-
-
 @app.command()
 def schedule_job(
     ctx: typer.Context,
