@@ -194,7 +194,7 @@ def create_bucket(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
 ) -> None:
     """Create new bucket."""
@@ -225,7 +225,7 @@ def delete_bucket(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
 ) -> None:
     """Delete bucket."""
@@ -244,17 +244,17 @@ def create_object(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     object_name: str = typer.Argument(
         ...,
         help="Object name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     file: str = typer.Argument(
         ...,
         help="Path to the object file.",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
 ) -> None:
     """Create object."""
@@ -276,7 +276,7 @@ def list_objects(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
 ) -> None:
     """List objects."""
@@ -295,17 +295,17 @@ def get_object(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     object_name: str = typer.Argument(
         ...,
         help="Object name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     file: str = typer.Argument(
         ...,
         help="Path to file where to store the object.",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
 ) -> None:
     """Get object."""
@@ -328,12 +328,12 @@ def delete_object(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     object_name: str = typer.Argument(
         ...,
         help="Object name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
 ) -> None:
     """Delete object."""
@@ -352,17 +352,17 @@ def set_object_tags(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     object_name: str = typer.Argument(
         ...,
         help="Object name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     tags: typing.List[str] = typer.Argument(
         ...,
         help="Tags as pairs of key=value",
-        callback=util.sanitize,
+        callback=util.validate_strings_are_not_empty,
     ),
 ) -> None:
     """Set object tags. Be aware that this command overwrites any tags that are already set to the object."""
@@ -389,12 +389,12 @@ def get_object_tags(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     object_name: str = typer.Argument(
         ...,
         help="Object name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
 ) -> None:
     """Get object tags."""
@@ -413,12 +413,12 @@ def delete_object_tags(
     bucket_name: str = typer.Argument(
         ...,
         help="Bucket name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
     object_name: str = typer.Argument(
         ...,
         help="Object name",
-        callback=util.sanitize,
+        callback=util.validate_string_not_empty,
     ),
 ) -> None:
     """Delete object tags."""
